from vdocipher.resources.request import authenticate
from vdocipher.resources.video import Video, UploadCredentials
from vdocipher.resources.otp import OTP
from vdocipher.resources.annotate import Annotate
from vdocipher.resources.license_rules import LicenseRules
